@@ -201,7 +201,7 @@ class ReaderThread(threading.Thread):
         except ImportError:
             from Queue import Queue
 
-        self.setDaemon(True)
+        self.daemon = True
         self._buffer = b''
         self.sock = sock
         self._queue = Queue()
@@ -382,7 +382,7 @@ def read_process(stream, buffer, debug_stream, stream_name, finish):
 
 def start_in_daemon_thread(target, args):
     t0 = threading.Thread(target=target, args=args)
-    t0.setDaemon(True)
+    t0.daemon = True
     t0.start()
 
 
@@ -430,7 +430,7 @@ class DebuggerRunner(object):
         return args + ret
 
     @contextmanager
-    def check_case(self, writer_class, wait_for_port=True):
+    def check_case(self, writer_class, wait_for_port=True, wait_for_initialization=True):
         try:
             if callable(writer_class):
                 writer = writer_class()
@@ -451,7 +451,11 @@ class DebuggerRunner(object):
 
                 with self.run_process(args, writer) as dct_with_stdout_stder:
                     try:
-                        if wait_for_port:
+                        if not wait_for_initialization:
+                            # The use-case for this is that the debugger can't even start-up in this
+                            # scenario, as such, sleep a bit so that the output can be collected.
+                            time.sleep(1)
+                        elif wait_for_port:
                             wait_for_condition(lambda: writer.finished_initialization)
                     except TimeoutError:
                         sys.stderr.write('Timed out waiting for initialization\n')
@@ -667,7 +671,7 @@ class AbstractWriterThread(threading.Thread):
     def __init__(self, *args, **kwargs):
         threading.Thread.__init__(self, *args, **kwargs)
         self.process = None  # Set after the process is created.
-        self.setDaemon(True)
+        self.daemon = True
         self.finished_ok = False
         self.finished_initialization = False
         self._next_breakpoint_id = 0
@@ -1391,7 +1395,10 @@ class AbstractWriterThread(threading.Thread):
         self.write("%s\t%s\t%s\t%s\t%s\t%s" % (CMD_GET_SMART_STEP_INTO_VARIANTS, self.next_seq(), thread_id, frame_id, start_line, end_line))
         msg = self.wait_for_message(CMD_GET_SMART_STEP_INTO_VARIANTS)
         if msg.variant:
-            variant_info = [(variant['name'], variant['isVisited'], variant['line'], variant['callOrder'], variant['offset']) for variant in msg.variant]
+            variant_info = [
+                (variant['name'], variant['isVisited'], variant['line'], variant['callOrder'], variant['offset'], variant['childOffset'])
+                for variant in msg.variant
+            ]
             return variant_info
         return []
 
